<template>
  <div id="myPieChart" :style="{ height: height, width: width }" />
</template>

<script>
// import echarts from 'echarts'
import * as echarts from 'echarts'
require('echarts/theme/macarons') // echarts theme
// import resize from '@/components/Echarts/mixins/resize'
export default {
  // mixins: [resize],
  props: {
    className: {
      type: String,
      default: 'chart'
    },
    width: {
      type: String,
      default: '100%'
    },
    height: {
      type: String,
      default: '290px'
    },
    cylindricalityData: {
      type: Array,
      required: false,
      default: () => []
    }
  },
  data() {
    return {
      chart: null,
      seriesData: [],
      namelist: []
    }
  },
  watch: {
    cylindricalityData: {
      handler(newVal) {
        console.log('newVal', newVal)
        this.seriesData = []
        this.namelist = []
        const arr = []

        newVal.forEach(item => {
          arr.push(item.value)
          this.namelist.push(item.name)
        })
        this.seriesData = [
          {
            type: 'bar',
            barWidth: '40%',
            data: arr
          }
        ]
        console.log('this.seriesData', this.seriesData)
        console.log('this.namelist', this.namelist)
        this.$nextTick(() => {
          this.initChart()
        })
      },
      deep: true,
      immediate: true
    }
  },
  mounted() {
    this.$nextTick(() => {
      this.initChart()
    })
  },
  beforeDestroy() {
    if (!this.chart) {
      return
    }
    this.chart.dispose()
    this.chart = null
  },
  methods: {
    initChart() {
      if (this.chart) {
        this.chart.dispose()
      }
      const chartDom = document.getElementById('myPieChart')
      this.chart = echarts.init(chartDom)
      this.chart.clear()
      this.setOptions()
    },
    setOptions() {
      // function fontSize(res) {
      //     let clientWidth =
      //         window.innerWidth ||
      //         document.documentElement.clientWidth ||
      //         document.body.clientWidth
      //     if (!clientWidth) return
      //     let fontSize = 100 * (clientWidth / 1920)
      //     return res * fontSize
      // }

      this.chart.setOption(
        {
          tooltip: {
            trigger: 'axis',
            backgroundColor: 'rgba(255,255,255,.8)', // 通过设置rgba调节背景颜色与透明度
            color: 'gray',
            axisPointer: {
              type: 'line'
            }
          },
          grid: {
            left: '3%',
            right: '4%',
            bottom: '3%',
            containLabel: true
          },
          xAxis: [
            {
              type: 'category',
              data: this.namelist,
              axisTick: {
                show: false,
                alignWithLabel: true
              },
              axisLine: {
                show: false
              },
              axisLabel: {
                color: '#989898'
              }
            }
          ],
          yAxis: [
            {
              type: 'value',
              axisTick: {
                show: false
              },
              axisLine: {
                show: false
              },
              splitLine: {
                lineStyle: {
                  color: '#ebebeb'
                }
              },
              axisLabel: {
                color: '#8c8c8c'
              }
            }
          ],
          series: this.seriesData
        },
        true
      )
      this.chart.resize()
      window.onresize = this.chart.resize
    }
  }
}
</script>

